# Copyright (c) 2000-2007, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

# If you want repolib package to be built,
# issue the following: 'rpmbuild --with repolib'

%define _with_repolib 1

%define with_repolib %{?_with_repolib:1}%{!?_with_repolib:0}
%define without_repolib %{!?_with_repolib:1}%{?_with_repolib:0}

%define repodir %{_javadir}/repository.jboss.com/jgroups/2.4.1.SP3-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

# If you don't want to run the unit tests
# give rpmbuild option '--without tests'

%define with_tests %{!?_without_tests:1}%{?_without_tests:0}
%define without_tests %{?_without_tests:1}%{!?_without_tests:0}


%define section free

Name:           jgroups
Version:        2.4.1.3
Release:        1jpp.ep1.1%{?dist}
Epoch:          0
Summary:        Toolkit for reliable multicast communication.
License:        LGPL
URL:            http://www.jgroups.org/
Group:          Development/LIbraries/Java
Source0:        http://download.sourceforge.net/sourceforge/javagroups/JGroups-2.4.1-sp3.src.zip
Patch0:         jgroups-2.3-build_xml.patch
Source1:	jgroups-component-info.xml
# To use JGroups one needs:
# commons-logging.jar
Requires:       jakarta-commons-logging
# concurrent.jar
Requires:       concurrent
# log4j.jar
Requires:       log4j
# To run JGroups you need to have an XML parser installed on your system.
# If you use JDK 1.4 or higher, you can use the parser that is shipped with it.
Requires:       jaxp_parser_impl
# If you want to use the JGroups JMS protocol ( org.jgroups.protocols.JMS ),
# then you will also need to place jms.jar somewhere in your CLASSPATH. 
Requires:       jms
# Place the JAR files somewhere in your CLASSPATH , and you're ready to start
# using JGroups.

# FIXME Do we need bsh at run-time?
Requires:       bsh
#Optional:       mx4j

BuildRequires:  jpackage-utils >= 0:1.6
BuildRequires:  java-devel >= 0:1.5
BuildRequires:  ant >= 0:1.6
BuildRequires:  ant-junit
BuildRequires:  bsh
BuildRequires:  concurrent
BuildRequires:  jakarta-commons-logging
BuildRequires:  jaxp_parser_impl
BuildRequires:  jms
BuildRequires:  junit
BuildRequires:  log4j
BuildRequires:  mx4j
BuildRequires:  xalan-j2
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
JGroups is a toolkit for reliable multicast communication. (Note that
this doesn't necessarily mean IP Multicast, JGroups can also use
transports such as TCP). It can be used to create groups of processes
whose members can send messages to each other. The main features include

    * Group creation and deletion. Group members can be spread across
      LANs or WANs
    * Joining and leaving of groups
    * Membership detection and notification about joined/left/crashed members
    * Detection and removal of crashed members
    * Sending and receiving of member-to-group messages (point-to-multipoint)
    * Sending and receiving of member-to-member messages (point-to-point)

To use JGroups one needs:
 commons-logging.jar
 concurrent.jar
 log4j.jar

To run JGroups you need to have an XML parser installed on your system.
If you use JDK 1.4 or higher, you can use the parser that is shipped with it.

If you want to use the JGroups JMS protocol ( org.jgroups.protocols.JMS ),
then you will also need to place jms.jar somewhere in your CLASSPATH. 

Place the JAR files somewhere in your CLASSPATH , and you're ready to start
using JGroups.

%if %{with_repolib}
%package	 repolib
Summary:	 Artifacts to be uploaded to a repository library
Group:	Development/Libraries/Java

%description	 repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio
%endif

%package        javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation

%description    javadoc
%{summary}.

%package        manual
Summary:        Documents for %{name}
Group:          Development/Documentation

%description    manual
%{summary}.

%prep
%setup -q -n JGroups-2.4.1-sp3.src
for j in $(find . -name "*.jar"); do
    mv $j $j.no
done

# this test requires bouncycastle
rm tests/junit/org/jgroups/protocols/ENCRYPTAsymmetricTest.java

%patch0 -b .sav


tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{SOURCE1}

%build
export OPT_JAR_LIST="ant-launcher ant/ant-junit junit xalan-j2 xalan-j2-serializer"
pushd lib
ln -sf $(build-classpath ant) .
ln -sf $(build-classpath ant-launcher) .
ln -sf $(build-classpath ant/ant-junit) .
#BUILD/JGroups-2.4.1.src/lib/bcprov-jdk14-117.jar.no
ln -sf $(build-classpath bsh) .
ln -sf $(build-classpath commons-logging) .
ln -sf $(build-classpath concurrent) .
ln -sf $(build-classpath jms) .
ln -sf $(build-classpath junit) .
ln -sf $(build-classpath log4j) .
ln -sf $(build-classpath mx4j/mx4j-jmx) .
ln -sf $(build-classpath xalan-j2) .
ln -sf $(build-classpath xalan-j2-serializer) .
popd
%if %{without_tests}
ant jar javadoc gossip-service jgroups-service
%else
#export ANT_OPTS="-Djava.net.preferIPv4Stack=true"
ant jar javadoc gossip-service jgroups-service unittests testreport
%endif

%install
rm -rf $RPM_BUILD_ROOT

# jars
install -d -m 755 $RPM_BUILD_ROOT%{_javadir}
install -m 644 dist/%{name}-all.jar \
        $RPM_BUILD_ROOT%{_javadir}/%{name}-%{version}.jar
install -m 644 dist/%{name}-core.jar \
        $RPM_BUILD_ROOT%{_javadir}/%{name}-core-%{version}.jar
(cd $RPM_BUILD_ROOT%{_javadir} && for jar in *-%{version}*; do \
ln -sf ${jar} ${jar/-%{version}/}; done)

# javadoc
install -p -d -m 755 $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
cp -pr dist/javadoc/* $RPM_BUILD_ROOT%{_javadocdir}/%{name}-%{version}
(cd $RPM_BUILD_ROOT%{_javadocdir} && ln -sf %{name}-%{version} %{name})

# services
install -p -d -m 755 $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}
install -m 644 dist/%{name}*.sar \
        $RPM_BUILD_ROOT%{_datadir}/%{name}-%{version}

# docs
install -p -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
cp -pr doc/* $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}


%if %{with_repolib}
	install -d -m 755 $RPM_BUILD_ROOT%{repodir}
	install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
	install -m 755 %{SOURCE1} $RPM_BUILD_ROOT%{repodir}/component-info.xml
	install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{PATCH0} $RPM_BUILD_ROOT%{repodirsrc}
	install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
	cp $RPM_BUILD_ROOT%{_javadir}/jgroups.jar $RPM_BUILD_ROOT%{repodirlib}
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%post javadoc
rm -f %{_javadocdir}/%{name}
ln -s %{name}-%{version} %{_javadocdir}/%{name}

%postun javadoc
if [ $1 -eq 0 ]; then
  rm -f %{_javadocdir}/%{name}
fi

%files
%defattr(0644,root,root,0755)
%{_javadir}/*
%{_datadir}/%{name}-%{version}

%files javadoc
%defattr(0644,root,root,0755)
%dir %{_javadocdir}/%{name}-%{version}
%doc %{_javadocdir}/%{name}-%{version}/*
%ghost %dir %{_javadocdir}/%{name}

%files manual
%defattr(0644,root,root,0755)
%doc %{_docdir}/%{name}-%{version}


%if %{with_repolib}
%files repolib
%defattr(0644,root,root,0755)
%{repodir}
%endif

%changelog
* Tue May 01 2007 Fernando Nasser <fnasser@redhat.com> 0:2.4.1.3-1jpp.ep1.1
- Upgrade to 2.4.1.SP3

* Fri Apr 20 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.4.1.2-1jpp.ep1.2
- Fix repodir macro 

* Fri Apr 20 2007 Fernando Nasser <fnasser@redhat.com> 0:2.4.1.2-1jpp.ep1.1
- Upgrade to 2.4.1.SP2

* Tue Mar 13 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.4.1-1jpp.ep1.3
- Fix typo in repodir (again)

* Tue Mar 13 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.4.1-1jpp.ep1.2
- Add _javadir to repodir

* Tue Mar 13 2007 Fernando Nasser <fnasser@redhat.com> 0:2.4.1.1-1jpp.ep1.1
- Upgrade to 2.4.1.SP1

* Wed Mar 07 2007 Fernando Nasser <fnasser@redhat.com> 0:2.4.1-1jpp.el4ep1.5
- Make mx4j optional

* Tue Feb 20 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.4.1-1jpp.el4ep1.4
- Add -brew suffix

* Mon Feb 19 2007 Fernando Nasser <fnasser@redhat.com> 0:2.4.1-1jpp.el4ep1.3
- Build with Java 5, which is now required by the developers
  (will still run with Java 1.4.2)

* Sun Feb 18 2007 Vivek Lakshmanan <vivekl@redhat.com> 0:2.4.1-1jpp.el4ep1.2
- Add repolib support

* Sun Feb 18 2007 Fernando Nasser <fnasser@redhat.com> 0:2.4.1-1jpp.el4ep1.1
- Merge for upgrade

* Sat Feb 17 2007 Fernando Nasser <fnasser@redhat.com> 0:2.4.1-1jpp
- Upgrade to 2.4.1
- Add missing BR for ant-junit
- Add missing BR for xalan-j2
- Disable tests that refer to Java 5 classes
- Remove version and distribution tags

* Tue Aug 01 2006 Fernando Nasser <fnasser@redhat.com> 0:2.3-0.cr1.1jpp_1rh
- Merge for upgrade

* Mon Jun 12 2006 Ralph Apel <r.apel@r-apel.de> 0:2.3-0.cr1.1jpp
- upgrade to 2.3.CR1

* Wed Jun 07 2006 Fernando Nasser <fnasser@redhat.com> 0:2.2.9.2-1jpp_1rh
- Merge for upgrade

* Wed May 31 2006 Ralph Apel <r.apel@r-apel.de> 0:2.2.9.2-1jpp
- upgrade to 2.2.9.2

* Tue May 02 2006 Ralph Apel <r.apel@r-apel.de> 0:2.2.9.1-1jpp
- upgrade to 2.2.9.1

* Sat Jun 04 2005 Fernando Nasser <fnasser@redhat.com> 0:2.2.7-1jpp_1rh
- Merge for upgrade

* Sat Jun 04 2005 Fernando Nasser <fnasser@redhat.com> 0:2.2.7-1jpp
- upgrade to 2.2.7

* Thu Dec 02 2004 Fernando Nasser <fnasser@redhat.com> 0:2.2.6-1jpp_1rh
- First Red Hat release

* Thu Sep 16 2004 Ralph Apel <r.apel at r-apel.de> 0:2.2.6-1jpp
- upgrade to 2.2.6

* Sun Aug 23 2004 Randy Watler <rwatler at finali.com> - 0:2.2-3jpp
- Rebuild with ant-1.6.2

* Tue Jun 01 2004 Randy Watler <rwatler at finali.com> - 0:2.2-2jpp
- Upgrade to Ant 1.6.X

* Sun Jan 25 2004 David Walluck <david@anti-microsoft.org> 0:2.2-1jpp
- update source
